@@ -569,7 +569,7 @@ seafile_mark_file_locked (const char *repo_id, const char *path, GError **error)
         canon_path[len-1] = 0;
 
     ret = seaf_filelock_manager_mark_file_locked (seaf->filelock_mgr,
-                                                  repo_id, path, FALSE);
+                                                  repo_id, path, LOCKED_MANUAL);
 
     g_free (canon_path);
     return ret;
