@@ -137,14 +137,19 @@ checkdir (const char *dir)
 int
 checkdir_with_mkdir (const char *dir)
 {
-#ifdef WIN32
     int ret;
+#ifdef WIN32
     char *path = g_strdup(dir);
     char *p = (char *)path + strlen(path) - 1;
     while (*p == '\\' || *p == '/') *p-- = '\0';
     ret = g_mkdir_with_parents(path, 0755);
     g_free (path);
     return ret;
+#elif defined __APPLE__
+    char *dir_nfd = g_utf8_normalize (dir, -1, G_NORMALIZE_NFD);
+    ret = g_mkdir_with_parents(dir_nfd, 0755);
+    g_free (dir_nfd);
+    return ret;
 #else
     return g_mkdir_with_parents(dir, 0755);
 #endif
@@ -476,9 +481,9 @@ seaf_set_file_time (const char *path, guint64 mtime)
 int
 seaf_util_unlink (const char *path)
 {
+    int ret = 0;
 #ifdef WIN32
     wchar_t *wpath = win32_long_path (path);
-    int ret = 0;
 
     if (!DeleteFileW (wpath)) {
         ret = -1;
@@ -487,6 +492,11 @@ seaf_util_unlink (const char *path)
 
     g_free (wpath);
     return ret;
+#elif defined __APPLE__
+    char *path_nfd = g_utf8_normalize (path, -1, G_NORMALIZE_NFD);
+    ret = unlink (path_nfd);
+    g_free (path_nfd);
+    return ret;
 #else
     return unlink (path);
 #endif
@@ -495,9 +505,9 @@ seaf_util_unlink (const char *path)
 int
 seaf_util_rmdir (const char *path)
 {
+    int ret = 0;
 #ifdef WIN32
     wchar_t *wpath = win32_long_path (path);
-    int ret = 0;
 
     if (!RemoveDirectoryW (wpath)) {
         ret = -1;
@@ -506,6 +516,11 @@ seaf_util_rmdir (const char *path)
 
     g_free (wpath);
     return ret;
+#elif defined __APPLE__
+    char *path_nfd = g_utf8_normalize (path, -1, G_NORMALIZE_NFD);
+    ret = rmdir (path_nfd);
+    g_free (path_nfd);
+    return ret;
 #else
     return rmdir (path);
 #endif
@@ -514,9 +529,9 @@ seaf_util_rmdir (const char *path)
 int
 seaf_util_mkdir (const char *path, mode_t mode)
 {
+    int ret = 0;
 #ifdef WIN32
     wchar_t *wpath = win32_long_path (path);
-    int ret = 0;
 
     if (!CreateDirectoryW (wpath, NULL)) {
         ret = -1;
@@ -525,6 +540,11 @@ seaf_util_mkdir (const char *path, mode_t mode)
 
     g_free (wpath);
     return ret;
+#elif defined __APPLE__
+    char *path_nfd = g_utf8_normalize (path, -1, G_NORMALIZE_NFD);
+    ret = mkdir (path_nfd, mode);
+    g_free (path_nfd);
+    return ret;
 #else
     return mkdir (path, mode);
 #endif
@@ -562,6 +582,12 @@ seaf_util_open (const char *path, int flags)
 
     g_free (wpath);
     return fd;
+#elif defined __APPLE__
+    int ret = 0;
+    char *path_nfd = g_utf8_normalize (path, -1, G_NORMALIZE_NFD);
+    ret = open (path_nfd, flags);
+    g_free (path_nfd);
+    return ret;
 #else
     return open (path, flags);
 #endif
@@ -599,6 +625,12 @@ seaf_util_create (const char *path, int flags, mode_t mode)
 
     g_free (wpath);
     return fd;
+#elif defined __APPLE__
+    int ret = 0;
+    char *path_nfd = g_utf8_normalize (path, -1, G_NORMALIZE_NFD);
+    ret = open (path_nfd, flags, mode);
+    g_free (path_nfd);
+    return ret;
 #else
     return open (path, flags, mode);
 #endif
@@ -607,10 +639,10 @@ seaf_util_create (const char *path, int flags, mode_t mode)
 int
 seaf_util_rename (const char *oldpath, const char *newpath)
 {
+    int ret = 0;
 #ifdef WIN32
     wchar_t *oldpathw = win32_long_path (oldpath);
     wchar_t *newpathw = win32_long_path (newpath);
-    int ret = 0;
 
     if (!MoveFileExW (oldpathw, newpathw, MOVEFILE_REPLACE_EXISTING)) {
         ret = -1;
@@ -620,6 +652,13 @@ seaf_util_rename (const char *oldpath, const char *newpath)
     g_free (oldpathw);
     g_free (newpathw);
     return ret;
+#elif defined __APPLE__
+    char *oldpath_nfd = g_utf8_normalize (oldpath, -1, G_NORMALIZE_NFD);
+    char *newpath_nfd = g_utf8_normalize (newpath, -1, G_NORMALIZE_NFD);
+    ret = rename (oldpath_nfd, newpath_nfd);
+    g_free (oldpath_nfd);
+    g_free (newpath_nfd);
+    return ret;
 #else
     return rename (oldpath, newpath);
 #endif
@@ -638,6 +677,12 @@ seaf_util_exists (const char *path)
 
     g_free (wpath);
     return ret;
+#elif defined __APPLE__
+    int ret = 0;
+    char *path_nfd = g_utf8_normalize (path, -1, G_NORMALIZE_NFD);
+    ret = access (path_nfd, F_OK);
+    g_free (path_nfd);
+    return (ret == 0);
 #else
     return (access (path, F_OK) == 0);
 #endif
